# ProtoTorch Releases

## Release 0.5.0

- Breaking: Removed deprecated `prototorch.modules.Prototypes1D`.
  - Use `prototorch.components.LabeledComponents` instead.

## Release 0.2.0

- Fixes in example scripts.

## Release 0.1.1-dev0

- Minor bugfixes.
- 100% line coverage.

## Release 0.1.0-dev0

Initial public release of ProtoTorch.
